@@ -73,7 +73,7 @@ apriori <-  function(data, parameter = NULL, appearance = NULL, control = NULL)
     )    
 
     ## add count to quality
-    quality(result)$count <- quality(result)$support*length(data)
+    quality(result)$count <- as.integer(round(quality(result)$support*length(data)))
     
     if (is(result, "rules"))  { 
       ## validate sparse Matrix (this takes care of sorting vector i)
